@@ -1470,9 +1470,9 @@ def determine_statement_purpose(statement:str):
     return None
 
 def parse(sql):
-    _log("sql_parse.parse")
+    print("        sql_parse.parse")
     if _f.exists(sql):
-        _log(f"    Reading SQL file: {sql}")
+        print(f"    Reading SQL file: {sql}")
         sql = _f.readr(sql)
 
     if len(sql)== 0:
@@ -1480,7 +1480,7 @@ def parse(sql):
 
     sql = _csu.strip_empty_lines(sql)
     raw_statements = get_statements(sql)
-    # print(f"raw_statements: {raw_statements}")
+    print(f"raw_statements: {len(raw_statements)}")
     data = {
         "schemas":[],
         "tables":[],
